@@ -22,9 +22,7 @@ pub mod prelude;
 mod tests;
 pub(crate) mod utils;
 
-use arrow::{
-    error::Result as ArrowResult, json::Reader as ArrowJsonReader, record_batch::RecordBatch,
-};
+use arrow::{error::Result as ArrowResult, record_batch::RecordBatch};
 
 use polars_core::prelude::*;
 use std::io::{Read, Seek, Write};
@@ -66,16 +64,6 @@ pub trait ArrowReader {
     fn schema(&self) -> Arc<Schema>;
 }
 
-impl<R: Read> ArrowReader for ArrowJsonReader<R> {
-    fn next_record_batch(&mut self) -> ArrowResult<Option<RecordBatch>> {
-        self.next()
-    }
-
-    fn schema(&self) -> Arc<Schema> {
-        Arc::new((&*self.schema()).into())
-    }
-}
-
 #[cfg(any(feature = "ipc", feature = "parquet", feature = "json"))]
 pub(crate) fn finish_reader<R: ArrowReader>(
     mut reader: R,
